@@ -1,4 +1,8 @@
-#' Create a users distinguished name
+#' Create a users distinguished name (defunct)
+#' 
+#' This function is defunct. Distinguished names are deprecated in favor of EDI 
+#' IDs. An EDI ID can be obtained from the EDI Identity and Access 
+#' Manager (\url{https://auth.edirepository.org/auth/ui/signin}).
 #'
 #' @param userId (character) User identifier of an EDI data repository account
 #' @param ou (character) Organizational unit in which \code{userId} belongs.
@@ -12,6 +16,7 @@
 #' @export
 #'
 #' @examples
+#' \dontrun{
 #' # For an EDI account
 #' dn <- create_dn(userId = "my_userid", ou = "EDI")
 #' dn
@@ -19,7 +24,10 @@
 #' # For an LTER account
 #' dn <- create_dn(userId = "my_userid", ou = "LTER")
 #' dn
+#' }
 create_dn <- function(userId, ou = "EDI") {
+  .Defunct(msg = "'create_dn()' is defunct. Distinguished names are no longer 
+           used in EDI authentication. Use an EDI ID token instead.")
   ou <- toupper(ou)
   res <- paste0("uid=", userId, ",o=", ou, ",")
   if (ou == "EDI") {
