@@ -10,6 +10,7 @@ if (!nzchar(Sys.getenv("EDI_TOKEN"))) {
   if (dir.exists(vcr_dir)) {
     # Fake API token to fool our package
     Sys.setenv("EDI_TOKEN" = "foobar")
+    Sys.setenv("AUTH_TOKEN" = "foobar")
   } else {
     # If there's no mock files nor API token, impossible to run tests
     stop("No API key nor cassettes, tests cannot be run.",
@@ -23,4 +24,3 @@ invisible(vcr::vcr_configure(
   filter_request_headers = list(`auth-token` = "<<<not-my-bearer-token>>>"),
   filter_response_headers = list(`auth-token` = "<<<not-my-bearer-token>>>")
 ))
-vcr::check_cassette_names()
