@@ -36,17 +36,24 @@ testthat::test_that('Landing page URLs are constructed', {
 
 
 testthat::test_that("bake_cookie() works", {
-  token <- Sys.getenv("EDI_TOKEN")
+  edi_token <- Sys.getenv("EDI_TOKEN")
   Sys.setenv(EDI_TOKEN = "foobar")
+  auth_token <- Sys.getenv("AUTH_TOKEN")
+  Sys.setenv(AUTH_TOKEN = "foobar")
   res <- bake_cookie()
   expect_equal(class(res), "request")
-  Sys.setenv(EDI_TOKEN = token)
+  Sys.setenv(EDI_TOKEN = edi_token)
+  Sys.setenv(AUTH_TOKEN = auth_token)
 })
 
 
 
 testthat::test_that("create_test_eml() works", {
-  path <- create_test_eml(tempdir(), "edi.1.1")
+  path <- create_test_eml(
+    tempdir(), 
+    "edi.1.1", 
+    edi_id = "EDI-543afa80c859825d35d37d9111c24a4a65a0db9f"
+    )
   expect_true(file.exists(path))
 })
 
